==> aws-cdk.aws-route53recoverycontrol-1.138.2.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnCluster(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.ruleConfig))
        _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty(p.ruleConfig);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnControlPanel(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps, _aws_cdk_aws_route53recoverycontrol_CfnClusterProps, _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl, _aws_cdk_aws_route53recoverycontrol_CfnCluster, _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps, _aws_cdk_aws_route53recoverycontrol_CfnControlPanel, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-route53recoverycontrol-1.140.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnCluster(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnControlPanel(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.ruleConfig))
        _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty(p.ruleConfig);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty(p) {
}
function _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps, _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps, _aws_cdk_aws_route53recoverycontrol_CfnClusterProps, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl, _aws_cdk_aws_route53recoverycontrol_CfnCluster, _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty, _aws_cdk_aws_route53recoverycontrol_CfnControlPanel, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty };
module.exports.DeprecationError = DeprecationError;
